@@ -213,8 +213,10 @@ my %determiners = (
     'FilesUploadResult' => {  },
     'FillFormat' => {  },
     'FillOverlayEffect' => {  },
+    'FontData' => {  },
     'FontFallbackRule' => {  },
     'FontSet' => {  },
+    'FontsData' => {  },
     'GeometryPath' => {  },
     'GeometryPaths' => {  },
     'GlowEffect' => {  },
